(function() {
  var gm = google.maps,
    points = [],
    hspos = new gm.LatLng(52.246246, 21.002971),
    map, hsmarker,
    iconBase = new gm.Size(100, 133),
    shadowBase = new gm.Size(110, 146),
    infoWindowCurrentPoint = -1,
    infoWindowDefaultText = "<center><img src=\"/static/omgitspins.gif\" /></center>",
    infoWindow = new gm.InfoWindow({content:infoWindowDefaultText});
  function scaleIcon(url, base, zoom) {
    var fac = Math.max(Math.min(Math.pow(2, zoom / 2 - 6), 0.25), 0.0625);
    return new gm.MarkerImage(url, null, null,
        new gm.Point(base.width * fac, base.height * fac),
      new gm.Size(base.width * fac * 2, base.height * fac * 2))
  }
  function initialize() {
    var style = [
        {
          featureType: "water",
          stylers: [
            { lightness: -97 }
          ]
        },{
          featureType: "landscape",
          stylers: [
            { lightness: -74 },
            { hue: "#55ff00" }
          ]
        },{
          featureType: "administrative",
          elementType: "geometry",
          stylers: [
            { saturation: 82 },
            { hue: "#5eff00" },
            { gamma: 0.25 },
            { lightness: -36 },
            { visibility: "on" }
          ]
        },{
          featureType: "poi",
          stylers: [
            { visibility: "off" }
          ]
        }
      ],
      options = {
        center: hspos,
        zoom: 3,
        mapTypeId: gm.MapTypeId.ROADMAP,
        styles: style
      },
      hsimg = new gm.MarkerImage('/static/hs.png', null, null, new gm.Point(9.375, 9.375),
          new gm.Size(18.75, 18.75));
    map = new gm.Map(document.getElementById('map'), options);
    gm.event.addListener(map, 'zoom_changed', function() {
      points.forEach(function(p) {
        var img = scaleIcon('/static/marker.png', iconBase, map.getZoom()),
          shadow = scaleIcon('/static/shadow.png', shadowBase, map.getZoom());
        p.marker.setIcon(img);
        p.marker.setShadow(shadow);
      });
    });
    hsmarker = new gm.Marker({
      position: hspos,
      map: map,
      icon: hsimg,
      title: 'Warsaw Hackerspace'
    });
    poll = function() {
      var xhr = new XMLHttpRequest();
      xhr.onreadystatechange = function() {
        if(xhr.readyState === 4 && xhr.status === 200) {
          refresh(JSON.parse(xhr.responseText).points);
        }
      }
      xhr.open('GET', '/shamed', true);
      xhr.send(null);
    }
    window.setInterval(poll, 90000);
    poll();
  }
  function showShitForPoint(point) {
    var marker = point.marker, 
        pointID = point.id, 
        geo = point.geo,
        ip = point.ip,
        xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function()
    {
      if (xhr.readyState ===4 && xhr.status === 200)
      {
        if (infoWindowCurrentPoint == pointID)
	{
	  var bans = JSON.parse(xhr.responseText).bans,
	    content = "<center><b>" + ip + "</b><br/> (" + geo + ")</center><ul>\n";
          bans.forEach(function(b) {
            content += "<li><b>" + b.name + "</b> " + b.time + "</li>\n"
          });
          infoWindow.setContent(content);
	}
      }
    }
    infoWindowCurrentPoint = pointID;
    xhr.open('GET', '/shameon/' + pointID, true)
    xhr.send(null)
    infoWindow.setContent(infoWindowDefaultText);
    infoWindow.open(map, marker);
  }
  function createMarker(point) {
    var img = scaleIcon('/static/marker.png', iconBase, map.getZoom()),
      shadow = scaleIcon('/static/shadow.png', shadowBase, map.getZoom());
    var marker = new gm.Marker({
      position: new gm.LatLng(point.latitude, point.longitude),
      map: map,
      title: point.ip,
      icon: img,
      shadow: shadow
    });
    gm.event.addListener(marker, 'click', function() {
        showShitForPoint(point);
    });
    return marker;
  }
  function refresh(newPoints) {
    points.forEach(function(p) {
      p.marker.setMap(null);
    });
    newPoints.forEach(function(p) {
      p.marker = createMarker(p);
    });
    points = newPoints;
  }
  window.onload = initialize;
})()
